# NNERO

[![License: GPL v3](https://img.shields.io/badge/license-GPLv3-green.svg)](https://www.gnu.org/licenses/gpl-3.0)

[![Static Badge](https://img.shields.io/badge/physics-cosmology-darkblue)](https://en.wikipedia.org/wiki/Cosmology)
[![Static Badge](https://img.shields.io/badge/physics-21cm-yellow)](https://en.wikipedia.org/wiki/Hydrogen_line)

This is NNERO (**N**eural **N**etwork **E**mulator for **R**eionization and **O**ptical depth), a fast adaptative tool to emulate reionization history using a simple neural network architecture. 

## How to install and use NNERO?

```bash
pip install nnero
```